@@ -1,6 +1,6 @@
 //! Common structs and abstractions used by `kwap`
 
-#![doc(html_root_url = "https://docs.rs/kwap-common/0.3.0")]
+#![doc(html_root_url = "https://docs.rs/kwap-common/0.4.0")]
 #![cfg_attr(all(not(test), feature = "no_std"), no_std)]
 #![cfg_attr(not(test), forbid(missing_debug_implementations, unreachable_pub))]
 #![cfg_attr(not(test), deny(unsafe_code, missing_copy_implementations))]
@@ -9,6 +9,7 @@
 
 extern crate alloc;
 use alloc::vec::Vec;
+use core::ops::{Index, IndexMut};
 
 /// An ordered collection of some type `T`.
 ///
@@ -41,7 +42,15 @@ use alloc::vec::Vec;
 ///
 /// Less than ideal, but far preferable to coupling tightly to a particular collection and maintaining separate `alloc` and non-`alloc` implementations.
 pub trait Array<T>:
-  Default + Insert<T> + GetSize + Reserve + Extend<T> + FromIterator<T> + IntoIterator<Item = T>
+  Default
+  + Insert<T>
+  + Index<usize, Output = T>
+  + IndexMut<usize>
+  + GetSize
+  + Reserve
+  + Extend<T>
+  + FromIterator<T>
+  + IntoIterator<Item = T>
   where for<'a> &'a Self: IntoIterator<Item = &'a T>
 {
 }
